@@ -133,13 +133,21 @@ class ExecutorWorker(Worker):
         :type message: dict
         """
         logger.debug("handle message from executor worker")
-        handler_path = self.queue_mapping[message["queue_url"]]
+        handler_params = self.queue_mapping[message["queue_url"]]
+        if isinstance(handler_params, str):
+            handler_path = handler_params
+            handler_kwargs = {}
+        elif isinstance(handler_params, tuple) and len(handler_params)==2:
+            handler_path = handler_params[0]
+            handler_kwargs = handler_params[1]
+        else:
+            logger.error(f"Wrong argument type : {handler_params}")
         function_name = handler_path.split(".")[-1]
         function_path = ".".join(handler_path.split(".")[:-1])
 
         function_module = importlib.import_module(function_path)
         function = getattr(function_module, function_name)
-        function(message["message"])
+        function(message["message"], **handler_kwargs)
 
     def _acknowledge(self, message: Dict[str, Any], client):
         """
